<?php
/**
 * 2018-2022 MXB Informatica.
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to info@mxbinformatica.it so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    MXB Informatica <info@mxbinformatica.it>
 *  @copyright 2013-2022 MXB Informatica
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 */

/**
 * @since 1.5.0
 */

// DUPLICATE & CUSTOMIZE 1/1: set the class name as "yourname": Mxb_Delaypay_[Yourname]ValidationModuleFrontController
class Mxb_Delaypay_BankwireValidationModuleFrontController extends ModuleFrontController
{
    public function postProcess()
    {
        $cart = $this->context->cart;
        if ($cart->id_customer == 0 || $cart->id_address_delivery == 0 || $cart->id_address_invoice == 0 || !$this->module->active) {
            Tools::redirect('index.php?controller=order&step=1');
        }

        // Check that this payment option is still available in case the customer changed his address just before the end of the checkout process
        $authorized = false;
        foreach (Module::getPaymentModules() as $module) {
            if ($module['name'] == $this->module->name) { //'ps_checkpayment') {
                $authorized = true;
                break;
            }
        }

        if (!$authorized) {
            die($this->trans('This payment method is not available.', array(), 'Modules.Checkpayment.Shop'));
        }

        $customer = new Customer($cart->id_customer);
        if (!Validate::isLoadedObject($customer)) {
            Tools::redirect('index.php?controller=order&step=1');
        }

        $currency = $this->context->currency;
        $total = (float)$cart->getOrderTotal(true, Cart::BOTH);
        $mailVars =    array(
            '{payment_name}' => $this->module->getPaymentFullName(),
            '{payment_address}' => $this->module->ribaInstructions,
            '{payment_address_html}' => str_replace("\n", '<br />', $this->module->ribaInstructions)
        );
        //$this->module->validateOrder((int)$cart->id, Configuration::get($this->module->CONFIG_RIBA_ORDER_STATUS), $total, $this->module->ribaName, null, $mailVars, (int)$currency->id, false, $customer->secure_key);
        $this->module->validateOrder((int)$cart->id, $this->module->ribaOrderStatus, $total, $this->module->getPaymentFullName(), null, $mailVars, (int)$currency->id, false, $customer->secure_key);
        Tools::redirect(
            'index.php?controller=order-confirmation&id_cart=' . (int)$cart->id
            . '&id_module=' . (int)$this->module->id
            . '&id_order=' . $this->module->currentOrder
            . '&key='.$customer->secure_key
        );
    }
}
